@@ -2,7 +2,13 @@
 
 import argparse
 import logging
-from typing import Literal, Optional
+import sys
+from typing import Optional
+
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 
 try:
     from rich.logging import RichHandler
